function pingtypes = get_pingtypes(instclass, rawdir, rawfilebase, params);
% return a structure with fields:
%     available: cellarray of strings represenging available pingtypes
%     second_set: [0 or 1]  indicating if os, which set to read


if isa(instclass, 'nb')
   pingtypes.available  = {'nb'};
elseif isa(instclass, 'bb')   
   pingtypes.available  = {'nb'};
elseif isa(instclass, 'os')

   rawfile = fullfile(rawdir, [rawfilebase, '.raw']);
   %% try reading both.  building {'bb'} or {'nb'} or {'bb','nb'}
   data1 = read(instclass, rawfile, 'yearbase', params.yearbase, ...
                'ilist', 1,'second_set',0);

   data2 = read(instclass, rawfile, 'yearbase', params.yearbase, ...
                'ilist', 1,'second_set',1);
   
   %% state pingtypes
   if isempty(data1)
      pingtypes = [];
      fprintf('no data in file %s\n', rawfilebase)
      return
   else
      pingtypes.available = {data1.config.pingtype};
   end
   
   if ~isempty(data2)
      pingtypes.available{2} = data2.config.pingtype;  % should be 'nb';
   end
   
   %% now do the logic to find second_set
   if ismember(pingtypes.available, 'nb')
      if  strcmp(params.pingtype, 'second') | strcmp(params.pingtype, 'nb')
         pingtypes.second_set = 1;
      elseif  strcmp(params.pingtype, 'first') | strcmp(params.pingtype, 'bb')
         pingtypes.second_set = 0;         
      else
         fprintf('in %s, ping type %s not supported\n', mfilename, params.pingtype)
         pingtypes = [];
         return
      end
   else
         pingtypes.second_set = 0;         
   end
else
   fprintf('instrument class %s not supported\n', inst2str)
   pingtypes = [];
   return
end
